# Introduction
```
APIs for loginning some websites using requests.
You can star this repository to keep track of the project if it's helpful for you, thank you for your support.
```

# Documents
#### In Chinese
https://httpsgithubcomcharlespikachudecryptlogin.readthedocs.io/zh/latest/
#### In English
https://httpsgithubcomcharlespikachudecryptlogin.readthedocs.io/en/latest/

# Supported
|  Websites        | PC Mode | Mobile Mode | ScanQR Mode | in Chinese        |
|  :----:          | :----:  | :----:      | :----:      | :----:            |
|  Weibo           | ✓       | ✓           | ✓           | 新浪微博          |
|  Douban          | ✓       | ✗           | ✗           | 豆瓣              |
|  Github          | ✓       | ✗           | ✗           | Github            |
|  Music163        | ✓       | ✗           | ✗           | 网易云音乐        |
|  Zt12306         | ✓       | ✗           | ✗           | 中国铁路12306     |
|  QQZone          | ✗       | ✗           | ✓           | QQ空间            |
|  QQQun           | ✗       | ✗           | ✓           | QQ群              |
|  QQId			   | ✗       | ✗           | ✓           | 我的QQ中心        |
|  Zhihu		   | ✓       | ✗           | ✓           | 知乎         	 |
|  Bilibili		   | ✓       | ✓           | ✗           | B站               |
|  Toutiao		   | ✗       | ✗           | ✗           | 今日头条          |
|  Taobao          | ✗       | ✗           | ✓           | 淘宝              |
|  Jingdong        | ✗       | ✗           | ✓           | 京东              |
|  Ifeng           | ✓       | ✗           | ✗           | 凤凰网            |
|  Sohu            | ✗       | ✓           | ✗           | 搜狐              |
|  Zgconline       | ✓       | ✗           | ✗           | 中关村在线        |
|  Lagou           | ✗       | ✗           | ✗           | 拉勾网            |
|  Twitter         | ✗       | ✓           | ✗           | 推特              |
|  Vultr           | ✓       | ✗           | ✗           | Vultr             |
|  eSurfing        | ✓       | ✗           | ✗           | 天翼              |
|  Renren          | ✓       | ✗           | ✗           | 人人网            |
|  W3Cschool       | ✓       | ✗           | ✗           | W3Cschool(编程狮) |
|  Fishc           | ✓       | ✗           | ✗           | 鱼C论坛           |
|  Youdao          | ✓       | ✗           | ✗           | 有道              |
|  Baidupan        | ✓       | ✗           | ✗           | 百度网盘          |
|  Stackoverflow   | ✓       | ✗           | ✗           | Stackoverflow     |
|  CodaLab         | ✓       | ✗           | ✗           | CodaLab           |
|  PyPi            | ✓       | ✗           | ✗           | PyPi              | 
|  Xiami           | ✓       | ✗           | ✗           | 虾米音乐          |
|  Douyu           | ✗       | ✗           | ✓           | 斗鱼直播          |
|  Migu            | ✓       | ✗           | ✗           | 咪咕音乐          |
|  Qunar           | ✗       | ✗           | ✗           | 去哪儿旅行        |
|  Mieshop         | ✓       | ✗           | ✗           | 小米商城          |
|  Mpweixin        | ✓       | ✗           | ✗           | 微信公众号        |
|  Baidutieba      | ✗       | ✗           | ✓           | 百度贴吧          |
|  Dazhongdianping | ✗       | ✗           | ✓           | 大众点评          |
|  Jianguoyun      | ✓       | ✗           | ✗           | 坚果云            |
|  Cloud189        | ✓       | ✗           | ✗           | 天翼云盘          |
|  QQMusic         | ✗       | ✗           | ✓           | QQ音乐            |

# Some Cases by Using DecryptLogin
|  Name                       |   Introduction                                                   |   code                                                                                                       |  in Chinese                     |
|  :----:                     |   :----:                                                         |   :----:                                                                                                     |  :----:                         |
|  weiboMonitor               |   [click](https://mp.weixin.qq.com/s/uOT1cGqXkOq-Hdc8TVnglg)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/weiboMonitor)                  |  微博监控                       |
|  QQReport                   |	  [click](https://mp.weixin.qq.com/s/dsVtEp_TFeyeSAAUn1zFEw)     |	 [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/QQReports)                     |  生成QQ个人专属报告             |
|  bilibiliDownloadUserVideos |   [click](https://mp.weixin.qq.com/s/GaVW4_nbAaO0QvphI7QgnA)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/bilibiliDownloadUserVideos)    |  下载B站指定UP主的所有视频      |
|  NeteaseSongListDownloader  |   [click](https://mp.weixin.qq.com/s/_82U7luG6jmV-xb8-Qkiew)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/NeteaseSongListDownloader)     |  网易云个人歌单下载器           |
|  NeteaseListenLeaderboard   |   [click](https://mp.weixin.qq.com/s/Wlf1a82oACc9N7zGezcy8Q)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/NeteaseListenLeaderboard)      |  网易云个人听歌排行榜           |
|  userWeiboSpider            |   [click](https://mp.weixin.qq.com/s/-3BDTZAE1x7nfCLNq2mFBw)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/userWeiboSpider)               |  下载指定微博用户的所有微博数据 |
|  NeteaseSignin              |   [click](https://mp.weixin.qq.com/s/8d7smUSzW2ds1ypZq-yeFw)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/NeteaseSignin)                 |  网易云音乐自动签到             |  
|  weiboEmoji                 |   [click](https://mp.weixin.qq.com/s/QiPm4gyE8i5amR5gB3IbBA)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/weiboEmoji)                    |  微博表情包爬取                 |
|  weiboSender                |   [click](https://mp.weixin.qq.com/s/_aIY-iVj3xetfHQyMxflkg)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/weiboSender)                   |  大吼一声发微博                 |
|  tbgoods                    |   [click](https://mp.weixin.qq.com/s/NhK9eeWNXv_wPnolccRR-g)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/tbgoods)                       |  淘宝商品数据小爬虫             |
|  jdgoods                    |   [click](https://mp.weixin.qq.com/s/LXheJveR248ZW4SP5F6fjw)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/jdgoods)                       |  京东商品数据小爬虫             |
|  delallweibos               |   [click](https://mp.weixin.qq.com/s/E5Erg10FvyutEKaB_JGufA)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/delallweibos)                  |  批量删除微博                   |
|  ClearQzone                 |   [click](https://mp.weixin.qq.com/s/Fj9MQXXRZ8wuKiX3Tytx8A)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/ClearQzone)                    |  批量删除QQ空间说说             |
|  NeteaseEveryday            |   [click](https://mp.weixin.qq.com/s/tliFa5CYVEirMEyUj0jPbg)     |   [click](https://github.com/CharlesPikachu/DecryptLogin/tree/master/examples/NeteaseEveryday)               |  在终端看网易云每日歌曲推荐     |

# Install
#### Pip install
```
run "pip install DecryptLogin"
```
#### Source code install
```sh
(1) Offline
Step1: git clone https://github.com/CharlesPikachu/DecryptLogin.git
Step2: cd DecryptLogin -> run "python setup.py install"
(2) Online
run "pip install git+https://github.com/CharlesPikachu/DecryptLogin.git@master"
```

# Quick Start
```python
from DecryptLogin import login

lg = login.Login()
infos_return, session = lg.douban(username[telephone], password)
infos_return, session = lg.github(username[email], password)
infos_return, session = lg.weibo()
infos_return, session = lg.music163(username[telephone/email], password)
infos_return, session = lg.zt12306(username[telephone], password)
infos_return, session = lg.QQZone()
infos_return, session = lg.QQQun()
infos_return, session = lg.QQId()
infos_return, session = lg.zhihu()
infos_return, session = lg.bilibili(username, password)
infos_return, session = lg.toutiao(username, password)
infos_return, session = lg.taobao()
infos_return, session = lg.jingdong()
infos_return, session = lg.ifeng(username, password)
infos_return, session = lg.sohu(username, password)
infos_return, session = lg.zgconline(username, password)
infos_return, session = lg.lagou(username, password)
infos_return, session = lg.twitter(username, password)
infos_return, session = lg.vultr(username, password)
infos_return, session = lg.eSurfing(username, password)
infos_return, session = lg.renren(username, password)
infos_return, session = lg.w3cschool(username, password)
infos_return, session = lg.fishc(username, password)
infos_return, session = lg.youdao(username, password)
infos_return, session = lg.baidupan(username, password)
infos_return, session = lg.stackoverflow(username, password)
infos_return, session = lg.codalab(username, password)
infos_return, session = lg.pypi(username, password)
infos_return, session = lg.xiami(username, password)
infos_return, session = lg.douyu()
infos_return, session = lg.migu(username, password)
infos_return, session = lg.qunar(username, password)
infos_return, session = lg.mieshop(username, password)
infos_return, session = lg.mpweixin(username, password)
infos_return, session = lg.baidutieba()
infos_return, session = lg.dazhongdianping()
infos_return, session = lg.jianguoyun(username, password)
infos_return, session = lg.cloud189(username, password)
infos_return, session = lg.qqmusic()
```

# Thanks List
|  Author                                            |           Time            |   Contribution                                     |
|  :----:                                            |           :----:          |   :----:                                           |
|  @[skygongque](https://github.com/skygongque)      |           2020-02-13      |   add verification code processing in (weibo, pc)  |

# More
#### WeChat Official Accounts
*Charles_pikachu*  
![img](pikachu.jpg)